@@ -13,10 +13,14 @@ from archimedes.data.api import (
     get,
     get_latest,
     list_ids,
+    list_series_price_areas,
     get_predictions,
     list_prediction_ids,
     get_predictions_ref_dts,
     store_prediction,
+    forecast_list_ref_times,
+    forecast_diff,
+    forecast_get_by_ref_time_interval,
 )
 from archimedes.organizer.organizer import (
     run,
@@ -39,6 +43,7 @@ __all__ = [
     "get",
     "get_latest",
     "list_ids",
+    "list_series_price_areas",
     "load_latest_model",
     "log",
     "run",
@@ -52,4 +57,7 @@ __all__ = [
     "list_prediction_ids",
     "store_model",
     "store_prediction",
+    "forecast_list_ref_times",
+    "forecast_diff",
+    "forecast_get_by_ref_time_interval",
 ]
